@@ -1,7 +1,7 @@
 //! Completion for associated items in a trait implementation.
 //!
 //! This module adds the completion items related to implementing associated
-//! items within a `impl Trait for Struct` block. The current context node
+//! items within an `impl Trait for Struct` block. The current context node
 //! must be within either a `FN`, `TYPE_ALIAS`, or `CONST` node
 //! and an direct child of an `IMPL`.
 //!
@@ -34,7 +34,7 @@
 use hir::{self, HasAttrs, HasSource};
 use ide_db::{path_transform::PathTransform, traits::get_missing_assoc_items, SymbolKind};
 use syntax::{
-    ast::{self, edit},
+    ast::{self, edit_in_place::AttrsOwnerEdit},
     display::function_declaration,
     AstNode, SyntaxElement, SyntaxKind, SyntaxNode, SyntaxToken, TextRange, T,
 };
@@ -186,17 +186,18 @@ fn get_transformed_assoc_item(
     let trait_ = impl_def.trait_(ctx.db)?;
     let source_scope = &ctx.sema.scope_for_def(trait_);
     let target_scope = &ctx.sema.scope(impl_def.source(ctx.db)?.syntax().value);
-    let transform = PathTransform {
-        subst: (trait_, impl_def.source(ctx.db)?.value),
-        source_scope,
+    let transform = PathTransform::trait_impl(
         target_scope,
-    };
+        source_scope,
+        trait_,
+        impl_def.source(ctx.db)?.value,
+    );
 
-    transform.apply(assoc_item.clone());
-    Some(match assoc_item {
-        ast::AssocItem::Fn(func) => ast::AssocItem::Fn(edit::remove_attrs_and_docs(&func)),
-        _ => assoc_item,
-    })
+    transform.apply(assoc_item.syntax());
+    if let ast::AssocItem::Fn(func) = &assoc_item {
+        func.remove_attrs_and_docs()
+    }
+    Some(assoc_item)
 }
 
 fn add_type_alias_impl(
@@ -252,7 +253,7 @@ fn add_const_impl(
 }
 
 fn make_const_compl_syntax(const_: &ast::Const) -> String {
-    let const_ = edit::remove_attrs_and_docs(const_);
+    const_.remove_attrs_and_docs();
 
     let const_start = const_.syntax().text_range().start();
     let const_end = const_.syntax().text_range().end();
@@ -299,29 +300,6 @@ mod tests {
         expect.assert_eq(&actual)
     }
 
-    #[test]
-    fn name_ref_function_type_const() {
-        check(
-            r#"
-trait Test {
-    type TestType;
-    const TEST_CONST: u16;
-    fn test();
-}
-struct T;
-
-impl Test for T {
-    t$0
-}
-"#,
-            expect![["
-ta type TestType = \n\
-ct const TEST_CONST: u16 = \n\
-fn fn test()
-"]],
-        );
-    }
-
     #[test]
     fn no_completion_inside_fn() {
         check(
@@ -572,27 +550,6 @@ impl Test for T {
         );
     }
 
-    #[test]
-    fn hide_implemented_fn() {
-        check(
-            r#"
-trait Test {
-    fn foo();
-    fn foo_bar();
-}
-struct T;
-
-impl Test for T {
-    fn foo() {}
-    fn f$0
-}
-"#,
-            expect![[r#"
-                fn fn foo_bar()
-            "#]],
-        );
-    }
-
     #[test]
     fn generic_fn() {
         check_edit(
